==> egov-common-1.0.3-sources.jar: com/gtis/plat/vo/PfUserVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;

public class PfUserVo implements Serializable {

    private static final long serialVersionUID = -5702093395225785269L;

    /**
     * 用户主键
     */
    private String userId;
    /**
     * 用户名
     */
    private String userName;
    /**
     * 登录名
     */
    private String loginName;
    /**
     * 登录密码
     */
    private String loginPassWord;
    /**
     * 手机号
     */
    private String mobilePhone;
    /**
     * 办公电话
     */
    private String officePhone;
    /**
     * 电子邮箱
     */
    private String email;
    /**
     * 员工编号
     */
    private String userNo;
    /**
     * 备注
     */
    private String remark;

    public String getUserNo() {
        return userNo;
    }

    public void setUserNo(String userNo) {
        this.userNo = userNo;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getLoginName() {
        return loginName;
    }

    public void setLoginName(String loginName) {
        this.loginName = loginName;
    }

    public String getLoginPassWord() {
        return loginPassWord;
    }

    public void setLoginPassWord(String loginPassWord) {
        this.loginPassWord = loginPassWord;
    }

    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getOfficePhone() {
        return officePhone;
    }

    public void setOfficePhone(String officePhone) {
        this.officePhone = officePhone;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}

==> egov-common-1.0.6-sources.jar: com/gtis/plat/vo/PfUserVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;

public class PfUserVo implements Serializable {

    private static final long serialVersionUID = -5702093395225785269L;

    /**
     * 用户主键
     */
    private String userId;
    /**
     * 用户名
     */
    private String userName;
    /**
     * 登录名
     */
    private String loginName;
    /**
     * 登录密码
     */
    private String loginPassWord;
    /**
     * 手机号
     */
    private String mobilePhone;
    /**
     * 办公电话
     */
    private String officePhone;
    /**
     * 电子邮箱
     */
    private String email;
    /**
     * 员工编号
     */
    private String userNo;
    /**
     * 备注
     */
    private String remark;

    /**
     * 职位
     */
    private String userPost;

    public String getUserPost() {
        return userPost;
    }

    public void setUserPost(String userPost) {
        this.userPost = userPost;
    }

    public String getUserNo() {
        return userNo;
    }

    public void setUserNo(String userNo) {
        this.userNo = userNo;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getLoginName() {
        return loginName;
    }

    public void setLoginName(String loginName) {
        this.loginName = loginName;
    }

    public String getLoginPassWord() {
        return loginPassWord;
    }

    public void setLoginPassWord(String loginPassWord) {
        this.loginPassWord = loginPassWord;
    }

    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getOfficePhone() {
        return officePhone;
    }

    public void setOfficePhone(String officePhone) {
        this.officePhone = officePhone;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}
